==> ulyxex.0.1.1.with-tinyMce.zip: pages/code/admin_link_modify.php <==
<?php
class LinkModify extends Admin {
	function __construct() {
		$this->h = New Html();
		$this->tr = New Translate();
		$this->queryCommonSelect = 	" SELECT ".
										LINKS.".*,".USERS.".ID USERLINKID";
		$this->queryCommonFrom = 	" FROM ".
										LINKS.
										" INNER JOIN ".USERS." ON ".LINKS.".USERID = ".USERS.".ID";
		$this->queryWhereArray = array();
	}
	public function link_params($id) {
		$query = "SELECT * FROM ".LINKS." WHERE ID = ".$id;
		$query = $this->q($query);
		$result = mysql_fetch_assoc($query);
		return $result;
	}
	public function update_link($linkId) {
		$hide = (isset($_POST['hide']))?1:0;
		$now = time();
		$date = date("Y-m-d H:i:s",$now);
		$query = "UPDATE ".LINKS." SET NAME = '".$this->h->safe($_POST['name'])."',".
						"DESCRIPTION = '".$this->h->safe($_POST['description'])."',".
						"LINK = '".$this->h->safe($_POST['linktext'])."',".
						"HIDE = '".$hide."'";
		$query .= isset($_POST['updateDate'])?",DATE = '".$date."'":"";
		$query .=		" WHERE ID = ".$linkId;
		$query = $this->q($query);
		$result = $this->h->h3("link updated !");
		return $result;
	}
	public function data_link($linkId) {
		$query = $this->queryCommonSelect.$this->queryCommonFrom;
		// 1) can create users etc.
		// 2) can create articles, pages and links
		// 3) can create articles everywhere
		// 4) can create articles only in sandbox
		switch ($_SESSION['level']) {
			case 1:
				$this->queryWhereArray = array(); 
				if ($_SESSION['userid'] != 1) {
					$this->queryWhereArray[] = " (".USERS.".USERLEVEL > ".$_SESSION['level']." OR ".USERS.".ID = ".$_SESSION['userid'].")"; // all level 2, 3 and 4 user's pages, user's pages  
					$this->queryWhereArray[] = USERS.".ID != 1"; // but not admin articles
				}
				$this->queryWhereArray[] = LINKS.".ID = ".$linkId;
				if (count($this->queryWhereArray) > 0) $query .= " WHERE ".implode(" AND ",$this->queryWhereArray);
				break;
			case 2:
				$this->queryWhereArray = array();
				$this->queryWhereArray[] = LINKS.".USERID = ".$_SESSION['userid'];
				$this->queryWhereArray[] = LINKS.".ID = ".$linkId;
				if (count($this->queryWhereArray) > 0) $query .= " WHERE ".implode(" AND ",$this->queryWhereArray);
				break;
		}
// print $query.$this->h->br();
// print $this->h->print_rr($_SESSION);
		$query = $this->q($query);
		if ($query) {
			$dat = mysql_fetch_assoc($query);
			$content = $this->h->input("hidden","link",$dat['ID']);
			$content .= $this->h->input("hidden","update",1);
			$params =  ($dat['HIDE'])?" checked=\"checked\"":null;
			$content .= $this->h->p($this->tr->ws("hide").$this->h->input("checkbox","hide","on",$params));
			$content .= $this->h->p($this->tr->ws("name")).$this->h->p($this->h->input("text","name",$dat['NAME'],"size=".FIELDWIDTH));
			$content .= $this->h->p($this->tr->w("linktext")).$this->h->p($this->h->input("text","linktext",$dat['LINK'],"size=".FIELDWIDTH));
			$content .= $this->h->p($this->tr->w("description")).$this->h->p($this->h->textarea($dat['DESCRIPTION'],"description",array(8,FIELDWIDTH)));
			$content .= $this->h->p($this->tr->ws("update date")."(".$dat['DATE'].")".$this->h->input("checkbox","updateDate","1"));
			$content .= $this->h->p($this->h->input("submit","save",$this->tr->w("update")));
			$result = $this->h->form($content,"link","post","admin.php?action=modify_link");
			return $result;
		}
	}
}
?>

==> ulyxex.0.1.2.with-tinyMce.zip: pages/code/admin_link_modify.php <==
<?php
class LinkModify extends Admin {
	function __construct() {
		$this->h = New Html();
		$this->tr = New Translate();
		$this->qSelect = 	" SELECT ".
										LINKS.".*,".USERS.".ID USERLINKID";
		$this->qFrom = 	" FROM ".
										LINKS.
										" INNER JOIN ".USERS." ON ".LINKS.".USERID = ".USERS.".ID";
		$this->qWhereArray = array();
	}
	public function link_params($id) {
		$query = "SELECT * FROM ".LINKS." WHERE ID = ".$id;
		$query = $this->q($query);
		$result = mysql_fetch_assoc($query);
		return $result;
	}
	public function update_link($linkId) {
		$hide = (isset($_POST['hide']))?1:0;
		$now = time();
		$date = date("Y-m-d H:i:s",$now);
		$query = "UPDATE ".LINKS." SET NAME = '".$this->h->safe($_POST['name'])."',".
						"DESCRIPTION = '".$this->h->safe($_POST['description'])."',".
						"LINK = '".$this->h->safe($_POST['linktext'])."',".
						"HIDE = '".$hide."'";
		$query .= isset($_POST['updateDate'])?",DATE = '".$date."'":"";
		$query .=		" WHERE ID = ".$linkId;
		$query = $this->q($query);
		$result = $this->h->h3($this->tr->ws("link").strip_tags($_POST['name']).$this->tr->wsp("updated !"),"style='color:red'");
		return $result;
	}
	public function data_link($linkId) {
		$query = $this->qSelect.$this->qFrom;
		// 1) can create users etc.
		// 2) can create articles, pages and links
		// 3) can create articles everywhere
		// 4) can create articles only in sandbox
		switch ($_SESSION['level']) {
			case 1:
				$this->qWhereArray = array(); 
				if ($_SESSION['userid'] != 1) {
					$this->qWhereArray[] = " (".USERS.".USERLEVEL > ".$_SESSION['level']." OR ".USERS.".ID = ".$_SESSION['userid'].")"; // all level 2, 3 and 4 user's pages, user's pages  
					$this->qWhereArray[] = USERS.".ID != 1"; // but not admin articles
				}
				$this->qWhereArray[] = LINKS.".ID = ".$linkId;
				if (count($this->qWhereArray) > 0) $query .= " WHERE ".implode(" AND ",$this->qWhereArray);
				break;
			case 2:
				$this->qWhereArray = array();
				$this->qWhereArray[] = LINKS.".USERID = ".$_SESSION['userid'];
				$this->qWhereArray[] = LINKS.".ID = ".$linkId;
				if (count($this->qWhereArray) > 0) $query .= " WHERE ".implode(" AND ",$this->qWhereArray);
				break;
		}
// print $query.$this->h->br();
// print $this->h->print_rr($_SESSION);
		$query = $this->q($query);
		if ($dat = mysql_fetch_assoc($query)) {
			$content = $this->h->input("hidden","update",1);
			$content .= $this->h->input("hidden","link",$dat['ID']);
			$params =  ($dat['HIDE'])?" checked=\"checked\"":null;
			$content .= $this->h->p("(id:".$dat['ID'].") ".$this->tr->ws("hide").$this->h->input("checkbox","hide","on",$params));
			$content .= $this->h->p($this->tr->ws("name")).$this->h->p($this->h->input("text","name",$dat['NAME'],"size=".FIELDWIDTH));
			$content .= $this->h->p($this->tr->w("linktext")).$this->h->p($this->h->input("text","linktext",$dat['LINK'],"size=".FIELDWIDTH));
			$content .= $this->h->p($this->tr->w("description")).$this->h->p($this->h->textarea($dat['DESCRIPTION'],"description",array(8,FIELDWIDTH)));
			$content .= $this->h->p($this->tr->ws("update date")."(".$dat['DATE'].")".$this->h->input("checkbox","updateDate","1"));
			$content .= $this->h->p($this->h->input("submit","save",$this->tr->w("update")));
			$result = $this->h->form($content,"link","post","admin.php?action=modify_link");
			return $result;
		}
	}
}
?>
